@@ -46,24 +46,22 @@ pub fn state(
                     }
                 }
             }
-        } else {
-            if is_zero_copy {
-                quote! {
-                    impl anchor_lang::__private::AccountSize for #struct_ident {
-                        fn size(&self) -> std::result::Result<u64, anchor_lang::solana_program::program_error::ProgramError> {
-                            let len = anchor_lang::__private::bytemuck::bytes_of(self).len() as u64;
-                            Ok(8 + len)
-                        }
+        } else if is_zero_copy {
+            quote! {
+                impl anchor_lang::__private::AccountSize for #struct_ident {
+                    fn size(&self) -> std::result::Result<u64, anchor_lang::solana_program::program_error::ProgramError> {
+                        let len = anchor_lang::__private::bytemuck::bytes_of(self).len() as u64;
+                        Ok(8 + len)
                     }
                 }
-            } else {
-                let size = proc_macro2::TokenStream::from(args.clone());
-                // Size override given to the macro. Use it.
-                quote! {
-                    impl anchor_lang::__private::AccountSize for #struct_ident {
-                        fn size(&self) -> std::result::Result<u64, anchor_lang::solana_program::program_error::ProgramError> {
-                            Ok(#size)
-                        }
+            }
+        } else {
+            let size = proc_macro2::TokenStream::from(args);
+            // Size override given to the macro. Use it.
+            quote! {
+                impl anchor_lang::__private::AccountSize for #struct_ident {
+                    fn size(&self) -> std::result::Result<u64, anchor_lang::solana_program::program_error::ProgramError> {
+                        Ok(#size)
                     }
                 }
             }
